Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(254)

Unified Diff: dart/lib/compiler/implementation/resolver.dart

Issue 10377166: Prepare to have more than one universe. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge
Patch Set: Created 8 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: dart/lib/compiler/implementation/resolver.dart
diff --git a/dart/lib/compiler/implementation/resolver.dart b/dart/lib/compiler/implementation/resolver.dart
index a19aab2b8e8b0d56f601cca2403e2a37ecca6ffa..4809b77617ee1d61aba0a9167cf84ef700cf3312 100644
--- a/dart/lib/compiler/implementation/resolver.dart
+++ b/dart/lib/compiler/implementation/resolver.dart
@@ -1733,8 +1733,8 @@ class SignatureResolver extends CommonResolverVisitor<Element> {
// Visit the value. The compile time constant handler will
// make sure it's a compile time constant.
resolveExpression(node.arguments.head);
- // TODO(ahe): Do not call addToWorkList, and make sure that element isn't null.
- if (element !== null) compiler.addToWorkList(element);
+ // TODO(ahe): Move this to codegen, and make sure that element isn't null.
+ if (element !== null) compiler.enqueuer.codegen.addToWorkList(element);
return element;
}
« no previous file with comments | « dart/lib/compiler/implementation/native_emitter.dart ('k') | dart/lib/compiler/implementation/scanner/scanner_task.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698